"use client"

import { useEffect, useState } from "react"
import Link from "next/link"

export default function CheckLessonsPage() {
  const [data, setData] = useState<any>(null)
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)

  useEffect(() => {
    async function fetchData() {
      try {
        const response = await fetch("/api/debug/check-lessons")
        const result = await response.json()

        if (result.success) {
          setData(result.data)
        } else {
          setError(result.error || "Une erreur est survenue")
        }
      } catch (error) {
        setError((error as Error).message)
      } finally {
        setLoading(false)
      }
    }

    fetchData()
  }, [])

  if (loading) {
    return <div className="p-8">Chargement...</div>
  }

  if (error) {
    return <div className="p-8 text-red-500">Erreur: {error}</div>
  }

  return (
    <div className="p-8">
      <h1 className="text-2xl font-bold mb-4">Vérification des fichiers de leçons</h1>

      {data && Object.entries(data).length > 0 ? (
        <div>
          {Object.entries(data).map(([chapterId, chapterData]: [string, any]) => (
            <div key={chapterId} className="mb-8 border p-4 rounded-lg">
              <h2 className="text-xl font-semibold mb-2">{chapterData.title}</h2>

              {chapterData.error ? (
                <div className="text-red-500 mb-2">Erreur: {chapterData.error}</div>
              ) : (
                <table className="w-full border-collapse">
                  <thead>
                    <tr className="bg-gray-100">
                      <th className="border p-2 text-left">Leçon</th>
                      <th className="border p-2 text-left">ID</th>
                      <th className="border p-2 text-left">Fichier attendu</th>
                      <th className="border p-2 text-left">Statut</th>
                      <th className="border p-2 text-left">Actions</th>
                    </tr>
                  </thead>
                  <tbody>
                    {chapterData.lessons.map((lesson: any) => (
                      <tr key={lesson.id} className={lesson.exists ? "bg-green-50" : "bg-red-50"}>
                        <td className="border p-2">{lesson.title}</td>
                        <td className="border p-2 font-mono text-sm">{lesson.id}</td>
                        <td className="border p-2 font-mono text-sm">{lesson.expectedFilename}</td>
                        <td className="border p-2">
                          {lesson.exists ? (
                            <span className="text-green-600">✓ Fichier trouvé</span>
                          ) : (
                            <span className="text-red-600">✗ Fichier manquant</span>
                          )}
                        </td>
                        <td className="border p-2">
                          {lesson.exists && (
                            <Link
                              href={`/chapitres/${chapterId}/lecons/${lesson.id}`}
                              className="text-blue-500 hover:underline"
                            >
                              Voir la leçon
                            </Link>
                          )}
                        </td>
                      </tr>
                    ))}
                  </tbody>
                </table>
              )}

              {!chapterData.error && chapterData.lessons.some((l: any) => !l.exists) && (
                <div className="mt-4">
                  <h3 className="font-semibold mb-2">Fichiers disponibles dans ce dossier:</h3>
                  <ul className="list-disc pl-6">
                    {chapterData.lessons[0]?.availableFiles?.map((file: string) => (
                      <li key={file} className="font-mono text-sm">
                        {file}
                      </li>
                    ))}
                  </ul>
                </div>
              )}
            </div>
          ))}
        </div>
      ) : (
        <p>Aucune donnée trouvée.</p>
      )}
    </div>
  )
}
